diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/config/Config.lb LinuxBIOSv2/src/config/Config.lb
--- LinuxBIOSv2.orig3/src/config/Config.lb	2006-10-24 22:16:55.000000000 +0000
+++ LinuxBIOSv2/src/config/Config.lb	2006-10-24 22:51:05.000000000 +0000
@@ -217,7 +217,7 @@
 # for now, this is just 'lib', but it may be more later. 
 dir /lib
 dir /console
-dir /stream
+dir /payload
 dir /devices
 dir /pc80
 dir /boot
diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/config/Options.lb LinuxBIOSv2/src/config/Options.lb
--- LinuxBIOSv2.orig3/src/config/Options.lb	2006-10-24 22:36:09.000000000 +0000
+++ LinuxBIOSv2/src/config/Options.lb	2006-10-24 22:51:05.000000000 +0000
@@ -607,7 +607,7 @@
 	default {0xffffffff - ROM_SIZE + ROM_SECTION_OFFSET + 1}
 	format "0x%x"
 	export always
-	comment "ROM stream start location"
+	comment "ROM boot image start location"
 end
 define CONFIG_COMPRESSED_PAYLOAD_NRV2B
 	default 0
diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/include/payload/read_bytes.h LinuxBIOSv2/src/include/payload/read_bytes.h
--- LinuxBIOSv2.orig3/src/include/payload/read_bytes.h	2006-10-24 22:16:39.000000000 +0000
+++ LinuxBIOSv2/src/include/payload/read_bytes.h	2006-10-24 22:51:05.000000000 +0000
@@ -1,13 +1,13 @@
-#ifndef STREAM_READ_BYTES_H
-#define STREAM_READ_BYTES_H
+#ifndef PAYLOAD_READ_BYTES_H
+#define PAYLOAD_READ_BYTES_H
 
 #include <stdint.h>
 
 typedef long byte_offset_t;
 
-extern int stream_init(void);
-extern byte_offset_t stream_read(void *vdest, byte_offset_t count);
-extern byte_offset_t stream_skip(byte_offset_t count);
-extern void stream_fini(void);
+extern int payload_init(void);
+extern byte_offset_t payload_read(void *vdest, byte_offset_t count);
+extern byte_offset_t payload_skip(byte_offset_t count);
+extern void payload_fini(void);
 
-#endif /* STREAM_READ_BYTES_H */
+#endif /* PAYLOAD_READ_BYTES_H */
diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/payload/Config.lb LinuxBIOSv2/src/payload/Config.lb
--- LinuxBIOSv2.orig3/src/payload/Config.lb	2006-10-24 22:36:11.000000000 +0000
+++ LinuxBIOSv2/src/payload/Config.lb	2006-10-24 22:51:05.000000000 +0000
@@ -5,19 +5,19 @@
 uses CONFIG_SERIAL_PAYLOAD
 
 if CONFIG_ROM_PAYLOAD
-  object rom_stream.o
+  object rom_payload.o
 end
 
 if CONFIG_IDE_PAYLOAD
   default CONFIG_IDE=1
-  object ide_stream.o
+  object ide_payload.o
 end
 
 if CONFIG_FS_PAYLOAD
-  object fs_stream.o
+  object fs_payload.o
   dir fs
 end
 
 if CONFIG_SERIAL_PAYLOAD
-  object serial_stream.o
+  object serial_payload.o
 end
diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/payload/fs_payload.c LinuxBIOSv2/src/payload/fs_payload.c
--- LinuxBIOSv2.orig3/src/payload/fs_payload.c	2006-10-24 22:16:46.000000000 +0000
+++ LinuxBIOSv2/src/payload/fs_payload.c	2006-10-24 22:51:05.000000000 +0000
@@ -1,24 +1,24 @@
 #include <console/console.h>
 #include <stdlib.h>
 #include <stddef.h>
-#include <stream/read_bytes.h>
+#include <payload/read_bytes.h>
 #include <string.h>
 #include <fs/fs.h>
 
 char *boot_file;
 
-int stream_init(void)
+int payload_init(void)
 {
 	return file_open(boot_file);
 }
 
 
-void stream_fini(void)
+void payload_fini(void)
 {
 	return;
 }
 
-byte_offset_t stream_skip(byte_offset_t count)
+byte_offset_t payload_skip(byte_offset_t count)
 {
 	unsigned long pos = file_pos();
 	if (file_seek(count+pos) != count+pos)
@@ -26,7 +26,7 @@
 	return count;
 }
 
-byte_offset_t stream_read(void *vdest, byte_offset_t count)
+byte_offset_t payload_read(void *vdest, byte_offset_t count)
 {
 	return file_read(vdest, count);
 }
diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/payload/ide_payload.c LinuxBIOSv2/src/payload/ide_payload.c
--- LinuxBIOSv2.orig3/src/payload/ide_payload.c	2006-10-24 22:16:46.000000000 +0000
+++ LinuxBIOSv2/src/payload/ide_payload.c	2006-10-24 22:51:05.000000000 +0000
@@ -1,7 +1,7 @@
 #include <console/console.h>
 #include <stdlib.h>
 #include <stddef.h>
-#include <stream/read_bytes.h>
+#include <payload/read_bytes.h>
 #include <delay.h>
 #include <string.h>
 #include <pc80/ide.h>
@@ -11,7 +11,7 @@
 #endif
 
 static unsigned long offset;
-int stream_init(void)
+int payload_init(void)
 {
 	int i,res;
 
@@ -36,7 +36,7 @@
 	return res;
 }
 
-void stream_fini(void)
+void payload_fini(void)
 {
 	return;
 }
@@ -44,12 +44,12 @@
 static unsigned char buffer[512];
 static unsigned int block_num = 0;
 static unsigned int first_fill = 1;
-static byte_offset_t stream_ide_read(void *vdest, byte_offset_t offset, byte_offset_t count)
+static byte_offset_t payload_ide_read(void *vdest, byte_offset_t offset, byte_offset_t count)
 {
 	byte_offset_t bytes = 0;
 	unsigned char *dest = vdest;
 
-	//printk_debug("stream_ide_read count = %x\n", count);
+	//printk_debug("payload_ide_read count = %x\n", count);
 	while (bytes < count) {
 		unsigned int byte_offset, len;
 
@@ -77,11 +77,11 @@
 	return bytes;
 }
 
-byte_offset_t stream_read(void *vdest, byte_offset_t count)
+byte_offset_t payload_read(void *vdest, byte_offset_t count)
 {
 	byte_offset_t len;
 
-	len = stream_ide_read(vdest, offset, count);
+	len = payload_ide_read(vdest, offset, count);
 	if (len > 0) {
 		offset += len;
 	}
@@ -89,7 +89,7 @@
 	return len;
 }
 
-byte_offset_t stream_skip(byte_offset_t count)
+byte_offset_t payload_skip(byte_offset_t count)
 {
 	offset += count;
 	return count;
diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/boot/elfboot.c LinuxBIOSv2/src/boot/elfboot.c
--- LinuxBIOSv2.orig3/src/boot/elfboot.c	2006-10-24 22:16:55.000000000 +0000
+++ LinuxBIOSv2/src/boot/elfboot.c	2006-10-24 22:51:05.000000000 +0000
@@ -4,7 +4,7 @@
 #include <boot/elf_boot.h>
 #include <boot/linuxbios_tables.h>
 #include <ip_checksum.h>
-#include <stream/read_bytes.h>
+#include <payload/read_bytes.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
@@ -290,7 +290,7 @@
 			seg->s_filesz = 0;
 		}
 
 		/* Order by stream offset */
 		new->next = seg;
 		new->prev = seg->prev;
 		seg->prev->next = new;
@@ -328,7 +328,7 @@
 		} else {
 			new->s_filesz = 0;
 		}
 		/* Order by stream offset */
 		new->next = seg->next;
 		new->prev = seg;
 		seg->next->prev = new;
@@ -396,7 +396,7 @@
 			if (new->s_offset < ptr->s_offset)
 				break;
 		}
 		/* Order by stream offset */
 		new->next = ptr;
 		new->prev = ptr->prev;
 		ptr->prev->next = new;
@@ -463,7 +463,7 @@
 		/* Skip the unused bytes */
 		skip_bytes = start_offset - offset;
 		if (skip_bytes && 
-			((result = stream_skip(skip_bytes)) != skip_bytes)) {
+			((result = payload_skip(skip_bytes)) != skip_bytes)) {
 			printk_err("ERROR: Skip of %ld bytes skipped %ld bytes\n",
 				skip_bytes, result);
 			goto out;
@@ -486,7 +486,7 @@
 		/* Read the segment into memory */
 		read_bytes = middle - dest;
 		if (read_bytes && 
-			((result = stream_read(dest, read_bytes)) != read_bytes)) {
+			((result = payload_read(dest, read_bytes)) != read_bytes)) {
 			printk_err("ERROR: Read of %ld bytes read %ld bytes...\n",
 				read_bytes, result);
 			goto out;
@@ -579,10 +579,10 @@
 		goto out;
 
 	printk_spew("verified segments\n");
-	/* Shutdown the stream device */
-	stream_fini();
+	/* Shutdown the payload device */
+	payload_fini();
 	
-	printk_spew("closed down stream\n");
+	printk_spew("closed down payload\n");
 	/* Reset to booting from this image as late as possible */
 	boot_successful();
 
@@ -612,13 +612,13 @@
 	printk_info("\n");
 	post_code(0xf8);
 
-	if (stream_init() < 0) {
+	if (payload_init() < 0) {
 		printk_err("Could not initialize driver...\n");
 		goto out;
 	}
 
 	/* Read in the initial ELF_HEAD_SIZE bytes */
-	if (stream_read(header, ELF_HEAD_SIZE) != ELF_HEAD_SIZE) {
+	if (payload_read(header, ELF_HEAD_SIZE) != ELF_HEAD_SIZE) {
 		printk_err("Read failed...\n");
 		goto out;
 	}
@@ -656,8 +656,8 @@
 		header + header_offset , ELF_HEAD_SIZE - header_offset);
  out:
 	if (!result) {
-		/* Shutdown the stream device */
-		stream_fini();
+		/* Shutdown the payload device */
+		payload_fini();
 
 		printk_err("Cannot Load ELF Image\n");
 
@@ -290,7 +290,7 @@
 		}
 
-		/* Order by stream offset */
+		/* Order by payload offset */
 		new->next = seg;
 		new->prev = seg->prev;
@@ -328,7 +328,7 @@
 			new->s_filesz = 0;
 		}
-		/* Order by stream offset */
+		/* Order by payload offset */
 		new->next = seg->next;
 		new->prev = seg;
@@ -396,7 +396,7 @@
 				break;
 		}
-		/* Order by stream offset */
+		/* Order by payload offset */
 		new->next = ptr;
 		new->prev = ptr->prev;
diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/payload/rom_payload.c LinuxBIOSv2/src/payload/rom_payload.c
--- LinuxBIOSv2.orig3/src/payload/rom_payload.c	2006-10-24 22:36:11.000000000 +0000
+++ LinuxBIOSv2/src/payload/rom_payload.c	2006-10-24 22:51:05.000000000 +0000
@@ -1,10 +1,10 @@
 #include <console/console.h>
 #include <stdlib.h>
 #include <stddef.h>
-#include <stream/read_bytes.h>
+#include <payload/read_bytes.h>
 #include <string.h>
 
-/* if they set the precompressed rom stream, they better have set a type */
+/* if they set the precompressed rom payload, they better have set a type */
 #if CONFIG_PRECOMPRESSED_PAYLOAD && ((!CONFIG_COMPRESSED_PAYLOAD_NRV2B) && (!CONFIG_COMPRESSED_PAYLOAD_LZMA))
 #error "You set CONFIG_PRECOMPRESSED_PAYLOAD but need to set CONFIG_COMPRESSED_PAYLOAD_NRV2B or CONFIG_COMPRESSED_PAYLOAD_LZMA"
 #endif
@@ -54,7 +54,7 @@
 uncompress(uint8_t * rom_start, uint8_t *dest )
 {
 #if (CONFIG_COMPRESSED_PAYLOAD_NRV2B) 
-	unsigned long ilen; // used compressed stream length
+	unsigned long ilen; // used compressed payload length
 	return unrv2b(rom_start, dest, &ilen);
 #endif
 #if (CONFIG_COMPRESSED_PAYLOAD_LZMA)
@@ -62,14 +62,14 @@
 #endif
 }
 #endif
-int stream_init(void)
+int payload_init(void)
 {
 #if (UNCOMPRESSER)
         unsigned char *dest;
         unsigned long olen;
 #endif
 
-	printk_debug("rom_stream: 0x%08lx - 0x%08lx\n",
+	printk_debug("rom_payload: 0x%08lx - 0x%08lx\n",
 		(unsigned long)rom_start,
 		(unsigned long)rom_end);
 
@@ -107,12 +107,12 @@
 }
 
 
-void stream_fini(void)
+void payload_fini(void)
 {
 	return;
 }
 
-byte_offset_t stream_skip(byte_offset_t count)
+byte_offset_t payload_skip(byte_offset_t count)
 {
 	byte_offset_t bytes;
 	bytes = count;
@@ -128,13 +128,13 @@
 	return bytes;
 }
 
-byte_offset_t stream_read(void *vdest, byte_offset_t count)
+byte_offset_t payload_read(void *vdest, byte_offset_t count)
 {
 	unsigned char *dest = vdest;
 	const unsigned char *src = rom;
 	byte_offset_t bytes;
 
-	bytes = stream_skip(count);
+	bytes = payload_skip(count);
 	memcpy(dest, src, bytes);
 	return bytes;
 }
diff -BurN --exclude '*~' LinuxBIOSv2.orig3/src/payload/serial_payload.c LinuxBIOSv2/src/payload/serial_payload.c
--- LinuxBIOSv2.orig3/src/payload/serial_payload.c	2006-10-24 22:19:52.000000000 +0000
+++ LinuxBIOSv2/src/payload/serial_payload.c	2006-10-24 22:51:05.000000000 +0000
@@ -1,10 +1,10 @@
 #include <console/console.h>
 #include <stdlib.h>
 #include <stddef.h>
-#include <stream/read_bytes.h>
+#include <payload/read_bytes.h>
 #include <string.h>
 
-/* if they set the precompressed rom stream, they better have set a type */
+/* if they set the precompressed rom payload, they better have set a type */
 #if CONFIG_PRECOMPRESSED_PAYLOAD && ((!CONFIG_COMPRESSED_PAYLOAD_NRV2B) && (!CONFIG_COMPRESSED_PAYLOAD_LZMA))
 #error "You set CONFIG_PRECOMPRESSED_PAYLOAD but need to set CONFIG_COMPRESSED_PAYLOAD_NRV2B or CONFIG_COMPRESSED_PAYLOAD_LZMA"
 #endif
@@ -24,11 +24,11 @@
 
 #include "../lib/xmodem.c"
 
-/* Blocks of RAM for storing stream data */
-static unsigned char *stream_start = (unsigned char *) 0x02000000;
-static unsigned char *stream_end;
+/* Blocks of RAM for storing payload data */
+static unsigned char *payload_start = (unsigned char *) 0x02000000;
+static unsigned char *payload_end;
 static unsigned char *temp_start = (unsigned char *) 0x03000000;
-static int stream_max_bytes = 0x00800000;
+static int payload_max_bytes = 0x00800000;
 
 #if HAVE_UNCOMPRESSER
 static unsigned long uncompress(uint8_t *src, uint8_t *dest)
@@ -43,50 +43,50 @@
 }
 #endif
 
-int stream_init(void)
+int payload_init(void)
 {
 	int len;
 
-	printk_debug("serial_stream: downloading to 0x%08lx; start XMODEM transfer now!\n", temp_start);
-	if ((len = xmodemReceive(temp_start, stream_max_bytes)) <= 0) {
-		printk_debug("\nserial_stream: XMODEM transfer failed\n");
+	printk_debug("serial_payload: downloading to 0x%08lx; start XMODEM transfer now!\n", temp_start);
+	if ((len = xmodemReceive(temp_start, payload_max_bytes)) <= 0) {
+		printk_debug("\nserial_payload: XMODEM transfer failed\n");
 		return -1;
 	}
-	printk_debug("\nserial_stream: XMODEM transfer complete; %d bytes received\n", len);
+	printk_debug("\nserial_payload: XMODEM transfer complete; %d bytes received\n", len);
 #if HAVE_UNCOMPRESSER
-	printk_debug("serial_stream: uncompressing to 0x%08lx\n", stream_start);
-	len = uncompress((uint8_t *) temp_start, (uint8_t *) stream_start);
-	printk_debug("serial_stream: %d bytes uncompressed\n", len);
+	printk_debug("serial_payload: uncompressing to 0x%08lx\n", payload_start);
+	len = uncompress((uint8_t *) temp_start, (uint8_t *) payload_start);
+	printk_debug("serial_payload: %d bytes uncompressed\n", len);
 #else
-	printk_debug("serial_stream: copying to 0x%08lx\n", stream_start);
-	memcpy(stream_start, temp_start, len);
+	printk_debug("serial_payload: copying to 0x%08lx\n", payload_start);
+	memcpy(payload_start, temp_start, len);
 #endif
-	stream_end = stream_start + len - 1;
+	payload_end = payload_start + len - 1;
 	return 0;
 }
 
-void stream_fini(void)
+void payload_fini(void)
 {
 }
 
-byte_offset_t stream_skip(byte_offset_t count)
+byte_offset_t payload_skip(byte_offset_t count)
 {
-	if ((stream_start + count) > stream_end) {
+	if ((payload_start + count) > payload_end) {
 		printk_warning("%6d:%s() - overflowed source buffer\n",
 			__LINE__, __FUNCTION__);
 		count = 0;
-		if (stream_start <= stream_end) {
-			count = (stream_end - stream_start) + 1;
+		if (payload_start <= payload_end) {
+			count = (payload_end - payload_start) + 1;
 		}
 	}
-	stream_start += count;
+	payload_start += count;
 	return count;
 }
 
-byte_offset_t stream_read(void *vdest, byte_offset_t count)
+byte_offset_t payload_read(void *vdest, byte_offset_t count)
 {
-	unsigned char *old_start = stream_start;
-	count = stream_skip(count);
+	unsigned char *old_start = payload_start;
+	count = payload_skip(count);
 	memcpy(vdest, old_start, count);
 	return count;
 }
